@@ -37,7 +37,6 @@
 
 #include "codeconv.h"
 #include "unmime.h"
-#include "base64.h"
 #include "quoted-printable.h"
 #include "utils.h"
 #include "prefs_common.h"
@@ -696,6 +695,8 @@ conv_get_fallback_for_private_encoding(const gchar *encoding)
 {
 	if (encoding && (encoding[0] == 'X' || encoding[0] == 'x') &&
 	    encoding[1] == '-') {
+		if (!g_ascii_strcasecmp(encoding, CS_X_MACCYR))
+			return CS_MACCYR;
 		if (!g_ascii_strcasecmp(encoding, CS_X_GBK))
 			return CS_GBK;
 	}
@@ -750,8 +751,17 @@ gchar *conv_codeset_strdup(const gchar *inbuf,
 	size_t len;
 	CodeConvFunc conv_func;
 
-	if (!strcmp2(src_code, dest_code))
+	if (!strcmp2(src_code, dest_code)) {
+		CharSet dest_charset = conv_get_charset_from_str(dest_code);
+		if (strict_mode && dest_charset == C_UTF_8) {
+			/* ensure valid UTF-8 if target is UTF-8 */
+			if (!g_utf8_validate(inbuf, -1, NULL)) {
+				return NULL;
+			}
+		}
+		/* otherwise, try for a lucky day */
 		return g_strdup(inbuf);
+	}
 
 	src_code = conv_get_fallback_for_private_encoding(src_code);
 	conv_func = conv_get_code_conv_func(src_code, dest_code);
@@ -1014,6 +1024,7 @@ static const struct {
 	{C_WINDOWS_1257,	CS_WINDOWS_1257},
 	{C_WINDOWS_1258,	CS_WINDOWS_1258},
 	{C_KOI8_R,		CS_KOI8_R},
+	{C_MACCYR,		CS_MACCYR},
 	{C_KOI8_T,		CS_KOI8_T},
 	{C_KOI8_U,		CS_KOI8_U},
 	{C_ISO_2022_JP,		CS_ISO_2022_JP},
@@ -1573,6 +1584,8 @@ gchar *conv_unmime_header(const gchar *str, const gchar *default_encoding,
 	}								\
 }
 
+#define B64LEN(len) ((len) / 3 * 4 + ((len) % 3 ? 4 : 0))
+
 void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 			gint header_len, gboolean addr_field,
 			const gchar *out_encoding_)
@@ -1719,11 +1732,12 @@ void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 					out_enc_str_len =
 						qp_get_q_encoding_len(out_str);
 
-				Xalloca(enc_str, out_enc_str_len + 1, );
 				if (use_base64)
-					base64_encode(enc_str, out_str, out_str_len);
-				else
+					enc_str = g_base64_encode(out_str, out_str_len);
+				else {
+					Xalloca(enc_str, out_enc_str_len + 1, );
 					qp_q_encode(enc_str, out_str);
+				}
 
 				g_free(out_str);
 
@@ -1732,6 +1746,10 @@ void conv_encode_header_full(gchar *dest, gint len, const gchar *src,
 				g_snprintf(destp, mime_block_len + 1,
 					   MIMESEP_BEGIN "%s%s%s" MIMESEP_END,
 					   out_encoding, mimesep_enc, enc_str);
+
+				if (use_base64)
+					g_free(enc_str);
+
 				destp += mime_block_len;
 				srcp += cur_len;
 
@@ -1755,6 +1773,8 @@ void conv_encode_header(gchar *dest, gint len, const gchar *src,
 }
 
 #undef LBREAK_IF_REQUIRED
+#undef B64LEN
+
 gchar *conv_filename_from_utf8(const gchar *utf8_file)
 {
 	gchar *fs_file;
