@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2015 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -218,14 +218,14 @@ void refresh_resolvers(void)
 {
 #ifdef G_OS_UNIX
 	static time_t resolv_conf_changed = (time_t)NULL;
-	struct stat s;
+	GStatBuf s;
 
 	/* This makes the glibc re-read resolv.conf, if it changed
 	 * since our startup. Maybe that should be #ifdef'ed, I don't
 	 * know if it'd work on BSDs.
 	 * Why doesn't the glibc do it by itself?
 	 */
-	if (stat("/etc/resolv.conf", &s) == 0) {
+	if (g_stat("/etc/resolv.conf", &s) == 0) {
 		if (s.st_mtime > resolv_conf_changed) {
 			resolv_conf_changed = s.st_mtime;
 			res_init();
@@ -830,7 +830,7 @@ static gboolean sock_connect_async_cb(GIOChannel *source,
 		close(fd);
 		log_error(LOG_PROTOCOL, _("%s:%d: connection failed (%s).\n"),
 			  conn_data->hostname, conn_data->port,
-			  strerror(val));
+			  g_strerror(val));
 		sock_connect_address_list_async(conn_data);
 		return FALSE;
 	}
@@ -1512,7 +1512,7 @@ gint fd_write_all(gint fd, const gchar *buf, gint len)
                         n = write(fd, buf, len);
 
 		if (n <= 0) {
-			log_error(LOG_PROTOCOL, _("write on fd%d: %s\n"), fd, strerror(errno));
+			log_error(LOG_PROTOCOL, _("write on fd%d: %s\n"), fd, g_strerror(errno));
 			return -1;
 		}
 		len -= n;
