@@ -158,7 +158,7 @@ GSList *template_read_config(void)
 	gchar *filename;
 	GDir *dir;
 	const gchar *dir_name;
-	struct stat s;
+	GStatBuf s;
 	Template *tmpl;
 	GSList *tmpl_list = NULL;
 
