@@ -163,8 +163,14 @@ static void folderview_col_resized	(GtkCMCList	*clist,
 					 gint		 width,
 					 FolderView	*folderview);
 
+static void mark_all_read_handler	(GtkAction	*action,
+					 gpointer	 data,
+					 gboolean	 recursive);
+
 static void mark_all_read_cb            (GtkAction 	*action,
 					 gpointer	 data);
+static void mark_all_read_recursive_cb  (GtkAction 	*action,
+					 gpointer	 data);
 
 static void folderview_empty_trash_cb	(GtkAction 	*action,
 					 gpointer	 data);
@@ -228,6 +234,7 @@ static GtkActionEntry folderview_common_popup_entries[] =
 {
 	{"FolderViewPopup",			NULL, "FolderViewPopup" },
 	{"FolderViewPopup/MarkAllRead",		NULL, N_("Mark all re_ad"), NULL, NULL, G_CALLBACK(mark_all_read_cb) },
+	{"FolderViewPopup/MarkAllReadRec",	NULL, N_("Mark all read recursi_vely"), NULL, NULL, G_CALLBACK(mark_all_read_recursive_cb) },
 	{"FolderViewPopup/---",			NULL, "---" },
 	{"FolderViewPopup/RunProcessing",	NULL, N_("R_un processing rules"), NULL, NULL, G_CALLBACK(folderview_run_processing_cb) },
 	{"FolderViewPopup/SearchFolder",	NULL, N_("_Search folder..."), NULL, NULL, G_CALLBACK(folderview_search_cb) },
@@ -809,20 +816,34 @@ void folderview_select(FolderView *folderview, FolderItem *item)
 }
 
 static void mark_all_read_cb(GtkAction *action, gpointer data)
+{
+	mark_all_read_handler(action, data, FALSE);
+}
+
+static void mark_all_read_recursive_cb(GtkAction *action, gpointer data)
+{
+	mark_all_read_handler(action, data, TRUE);
+}
+
+static void mark_all_read_handler(GtkAction *action, gpointer data, gboolean recursive)
 {
 	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	AlertValue val;
+	gchar *message;
 	
 	item = folderview_get_selected_item(folderview);
 	if (item == NULL)
 		return;
 
-	if (folderview->summaryview->folder_item != item
-	&&  prefs_common.ask_mark_all_read) {
+	message = recursive? _("Do you really want to mark all mails in this "
+			       "folder and its sub-folders as read?") :
+			     _("Do you really want to mark all mails in this "
+			       "folder as read?");
+	if (folderview->summaryview->folder_item != item &&
+	    prefs_common.ask_mark_all_read) {
 		val = alertpanel_full(_("Mark all as read"),
-			_("Do you really want to mark all mails in this "
-			  "folder as read?"), GTK_STOCK_NO, GTK_STOCK_YES, NULL,
+			  message, GTK_STOCK_NO, GTK_STOCK_YES, NULL,
 			  TRUE, NULL, ALERT_QUESTION, G_ALERTDEFAULT);
 
 		if ((val & ~G_ALERTDISABLE) != G_ALERTALTERNATE)
@@ -830,17 +851,19 @@ static void mark_all_read_cb(GtkAction *action, gpointer data)
 		else if (val & G_ALERTDISABLE)
 			prefs_common.ask_mark_all_read = FALSE;
 	}
-
 	
 	folder_item_update_freeze();
-	if (folderview->summaryview->folder_item != item)
+	if (folderview->summaryview->folder_item != item && !recursive)
 		summary_lock(folderview->summaryview);
 	else
 		summary_freeze(folderview->summaryview);
 		
-	folderutils_mark_all_read(item);
+	if (recursive)
+		folderutils_mark_all_read_recursive(item);
+	else
+		folderutils_mark_all_read(item);
 	
-	if (folderview->summaryview->folder_item != item)
+	if (folderview->summaryview->folder_item != item && !recursive)
 		summary_unlock(folderview->summaryview);
 	else
 		summary_thaw(folderview->summaryview);
@@ -857,11 +880,13 @@ static void folderview_select_node(FolderView *folderview, GtkCMCTreeNode *node)
 		return;
 	}
 
+	gtk_cmclist_freeze(GTK_CMCLIST(ctree));
 	gtkut_ctree_expand_parent_all(ctree, node);
 
 	folderview->open_folder = TRUE;
 	gtkut_ctree_set_focus_row(ctree, node);
 	gtk_cmctree_select(ctree, node);
+	gtk_cmclist_thaw(GTK_CMCLIST(ctree));
 	if ((folderview->summaryview->folder_item &&
 	    folderview->summaryview->folder_item->total_msgs > 0) ||
 	     prefs_common.layout_mode == SMALL_LAYOUT)
@@ -1820,6 +1845,7 @@ static void folderview_set_sens_and_popup_menu(FolderView *folderview, gint row,
 		fpopup->add_menuitems(ui_manager, item);
 
 	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "MarkAllRead", "FolderViewPopup/MarkAllRead", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "MarkAllReadRec", "FolderViewPopup/MarkAllReadRec", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Separator1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RunProcessing", "FolderViewPopup/RunProcessing", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SearchFolder", "FolderViewPopup/SearchFolder", GTK_UI_MANAGER_MENUITEM)
@@ -1850,6 +1876,7 @@ static void folderview_set_sens_and_popup_menu(FolderView *folderview, gint row,
 	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
 
 	SET_SENS("FolderViewPopup/MarkAllRead", item->unread_msgs >= 1);
+	SET_SENS("FolderViewPopup/MarkAllReadRec", folderview_have_unread_children(folderview,item));
 	SET_SENS("FolderViewPopup/SearchFolder", item->total_msgs >= 1 && 
 		 folderview->selected == folderview->opened);
 	SET_SENS("FolderViewPopup/Properties", TRUE);
@@ -2474,6 +2501,7 @@ void folderview_move_folder(FolderView *folderview, FolderItem *from_folder,
 
 	statusbar_verbosity_set(FALSE);
 	folder_item_update_freeze();
+	gtk_cmclist_freeze(GTK_CMCLIST(folderview->ctree));
 	if ((status = folder_item_move_to(from_folder, to_folder, &new_folder, copy)) == F_MOVE_OK) {
 		statusbar_verbosity_set(FALSE);
 		main_window_cursor_normal(folderview->mainwin);
@@ -2485,10 +2513,12 @@ void folderview_move_folder(FolderView *folderview, FolderItem *from_folder,
 			gtk_cmctree_find_by_row_data(GTK_CMCTREE(folderview->ctree), 
 				NULL, to_folder), new_folder->folder);
 		folderview_select(folderview, new_folder);
+		gtk_cmclist_thaw(GTK_CMCLIST(folderview->ctree));
 	} else {
 		statusbar_verbosity_set(FALSE);		
 		main_window_cursor_normal(folderview->mainwin);
 		STATUSBAR_POP(folderview->mainwin);
+		gtk_cmclist_thaw(GTK_CMCLIST(folderview->ctree));
 		folder_item_update_thaw();
 		switch (status) {
 		case F_MOVE_FAILED_DEST_IS_PARENT:
