@@ -3,6 +3,7 @@ static char *TEAM_LIST[] = {
 "Tristan Chabredier <wwp@claws-mail.org>",
 "Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
+"Charles Lehner <charles@claws-mail.org",
 "Colin Leroy <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
@@ -34,24 +35,23 @@ NULL
 
 static char *TRANS_TEAM_LIST[] = {
 "[bg] Yasen Pramatarov <yasen@lindeas.com>",
+"[ca] Carles Tubio Terrón <c@rles-tub.io>",
 "[cs] David Vachulka <david@konstrukce-cad.com>",
 "[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
 "[eo] Sian Mountbatten <poenikatu@fastmail.co.uk>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
+"     Carles Tubio Terrón <c@rles-tub.io>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
-"[fr] Colin Leroy <colin@colino.net>",
-"[he] Genghis Khan <genghiskhan@gmx.ca>",
+"[fr] Tristan Chabredier <wwp@claws-mail.org>",
+"[he] Isratine Citizen <genghiskhan@gmx.ca>",
 "[hu] Páder Rezső <rezso@rezso.net>",
 "[id] MSulchan Darmawan <bleketux@gmail.com>",
 "[lt] Mindaugas Baranauskas <embar@super.lt>",
-"[nb] Eyolf Østrem <eyolf@oestrem.com>",
+"[nb] Petter Adsen <petter@synth.no>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
-"[ru] Aleksei Miheev <aleksei@miheev.info>",
 "[sk] Slavko <slavino@slavino.sk>",
-"[sv] Andreas Rönnquist <gusnan@gusnan.se>",
-"[zh_CN] Rob <rbnwmk@gmail.com>",
-"[zh_TW] Rob <rbnwmk@gmail.com>",
+"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
 NULL
 };
 
@@ -97,6 +97,7 @@ static char *CONTRIBS_LIST[] = {
 "H. Merijn Brand",
 "Eugene Brevdo",
 "Sean Buckheister",
+"Anton Butanaev",
 "Henrik Carlqvist",
 "Luca Cavalli",
 "David Chalmers",
@@ -110,6 +111,7 @@ static char *CONTRIBS_LIST[] = {
 "Christian Cornelssen",
 "Palmer Dabbelt",
 "George Danchev",
+"Robert David",
 "Kevin Day",
 "Matthieu Dazy",
 "Ben Deering",
@@ -246,6 +248,7 @@ static char *CONTRIBS_LIST[] = {
 "Mohammed Sameer",
 "Tobias Sandhaas",
 "Peter Sarvas",
+"Oliver Schneider",
 "Torsten Schoenfeld",
 "Simon 'corecode' Schubert",
 "Kim Schulz",
@@ -277,6 +280,7 @@ static char *CONTRIBS_LIST[] = {
 "Petr Vanek",
 "Jeroen Versteeg",
 "Kevin Vigor",
+"Johan Vromans",
 "Botalov Vyacheslav",
 "Radek Vybiral",
 "Jonathan Ware",
@@ -290,6 +294,7 @@ static char *CONTRIBS_LIST[] = {
 "Yasumatsu",
 "Ralgh Young",
 "YUP",
+"Daniel Zaoui",
 "Gál Zoltán",
 "Marien Zwart",
 "Martin Zwickel",
