@@ -157,6 +157,9 @@ static void new_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 
+	if (!folder_local_name_ok(new_folder))
+		return;
+
 	name = trim_string(new_folder, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
 
@@ -187,6 +190,7 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 	gchar *message, *name;
 	AlertValue avalue;
 	gchar *old_id;
+	gint ret;
 
 	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
@@ -215,9 +219,10 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 		folderview->opened = NULL;
 	}
 
-	if (item->folder->klass->remove_folder(item->folder, item) < 0) {
+	if ((ret = item->folder->klass->remove_folder(item->folder, item)) < 0) {
 		folder_item_scan(item);
-		alertpanel_error(_("Can't remove the folder '%s'."), name);
+		alertpanel_error(_("Can't remove the folder '%s'\n\n%s."),
+				 name, g_strerror(-ret));
 		g_free(old_id);
 		return;
 	}
@@ -261,6 +266,9 @@ static void rename_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 
+	if (!folder_local_name_ok(new_folder))
+		return;
+
 	if (folder_find_child_item_by_name(folder_item_parent(item), new_folder)) {
 		name = trim_string(new_folder, 32);
 		alertpanel_error(_("The folder '%s' already exists."), name);
