@@ -1,7 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2014 Hiroyuki Yamamoto and the Claws Mail Team
- * Copyright (C) 2014 Ricardo Mones
+ * Copyright (C) 2014-2015 Ricardo Mones and the Claws Mail Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,11 +31,14 @@
 
 #include "defs.h"
 #include "libravatar_prefs.h"
+#include "libravatar_cache.h"
 #include "prefs_common.h"
 #include "prefs_gtk.h"
+#include "alertpanel.h"
 
 #define PREFS_BLOCK_NAME "Libravatar"
 #define NUM_DEF_BUTTONS 7
+#define CUSTOM_URL_BUTTON_INDEX 6
 /* cache interval goes from 1 hour to 30 days */
 #define INTERVAL_MIN_H 1.0
 #define INTERVAL_MAX_H 720.0
@@ -128,10 +130,83 @@ static GtkWidget *labeled_spinner_box(gchar *label, GtkWidget *spinner, gchar *u
 	return hbox;
 }
 
+static gchar *avatar_stats_label_markup(AvatarCacheStats *stats)
+{
+	if (stats == NULL)
+		return g_strdup(
+			_("<span color=\"red\">Error reading cache stats</span>"));
+
+	if (stats->errors > 0)
+		return g_markup_printf_escaped(
+			_("<span color=\"red\">Using %s in %d files, %d "
+			"directories, %d others and %d errors</span>"),
+			to_human_readable((goffset) stats->bytes),
+			stats->files,
+			stats->dirs,
+			stats->others,
+			stats->errors);
+
+	return g_strdup_printf(
+		_("Using %s in %d files, %d directories and %d others"),
+		to_human_readable((goffset) stats->bytes),
+		stats->files,
+		stats->dirs,
+		stats->others);
+}
+
+static void cache_clean_button_clicked_cb(GtkButton *button, gpointer data)
+{
+	GtkLabel *label = (GtkLabel *) data;
+	gint val = 0;
+	AvatarCleanupResult *acr;
+	guint misses;
+
+	val = alertpanel_full(_("Clear icon cache"),
+			_("Are you sure you want to remove all cached avatar icons?"),
+			GTK_STOCK_NO, GTK_STOCK_YES, NULL, FALSE,
+			NULL, ALERT_WARNING, G_ALERTDEFAULT);
+	if (val != G_ALERTALTERNATE)
+		return;
+
+	debug_print("cleaning missing cache");
+	misses = g_hash_table_size(libravatarmisses);
+	g_hash_table_remove_all(libravatarmisses);
+
+	debug_print("cleaning disk cache");
+	acr = libravatar_cache_clean();
+	if (acr == NULL) {
+		alertpanel_error(_("Not enough memory for operation"));
+		return;
+	}
+
+	if (acr->e_stat == 0 && acr->e_unlink == 0) {
+		alertpanel_notice(_("Icon cache successfully cleared:\n"
+			"• %u missing entries removed.\n"
+			"• %u files removed."),
+			misses, acr->removed);
+		gtk_label_set_markup(label,
+			_("<span color=\"#006400\">Icon cache succesfully cleared!</span>"));
+	}
+	else {
+		alertpanel_warning(_("Errors clearing icon cache:\n"
+			"• %u missing entries removed.\n"
+			"• %u files removed.\n"
+			"• %u files failed to be read.\n"
+			"• %u files couldn't be removed."),
+			misses, acr->removed, acr->e_stat, acr->e_unlink);
+		gtk_label_set_markup(label,
+			_("<span color=\"red\">Error clearing icon cache.</span>"));
+	}
+	gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+	g_free(acr);
+}
+
 static GtkWidget *p_create_frame_cache(struct LibravatarPrefsPage *page)
 {
-	GtkWidget *vbox, *checkbox, *spinner, *hbox;
+	GtkWidget *vbox, *checkbox, *spinner, *hbox, *label, *button;
 	GtkAdjustment *adj;
+	AvatarCacheStats *stats;
+	gchar *markup;
 
 	vbox =  gtk_vbox_new(FALSE, 6);
 
@@ -157,6 +232,29 @@ static GtkWidget *p_create_frame_cache(struct LibravatarPrefsPage *page)
 	gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
+	label = gtk_label_new(NULL);
+	gtk_widget_show(label);
+	stats = libravatar_cache_stats();
+	markup = avatar_stats_label_markup(stats);
+	gtk_label_set_markup(GTK_LABEL(label), markup);
+	g_free(markup);
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+
+	button = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
+	gtk_widget_show(button);
+	g_signal_connect(button, "clicked",
+		G_CALLBACK(cache_clean_button_clicked_cb), label);
+	gtk_widget_set_sensitive(button, (stats != NULL && stats->bytes > 0));
+
+	hbox = gtk_hbox_new(FALSE, 6);
+	gtk_widget_show(hbox);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
+	if (stats != NULL)
+		g_free(stats);
+
 	return vbox;
 }
 
@@ -178,10 +276,10 @@ static void default_mode_radio_button_cb(GtkToggleButton *button, gpointer data)
 			TRUE);
 
 	if (mode == DEF_MODE_NONE) {
-		prefs_common.enable_avatars = AVATARS_ENABLE_BOTH;
+		prefs_common_get_prefs()->enable_avatars = AVATARS_ENABLE_BOTH;
 	} else {
 		/* don't waste time with headers that won't be displayed */
-		prefs_common.enable_avatars = AVATARS_DISABLE;
+		prefs_common_get_prefs()->enable_avatars = AVATARS_DISABLE;
 		/* empty missing cache when switching to generated */
 		g_hash_table_remove_all(libravatarmisses);
 	}
@@ -199,7 +297,7 @@ static const guint radio_value[] = {
 
 static GtkWidget *p_create_frame_missing(struct LibravatarPrefsPage *page)
 {
-	GtkWidget *vbox, *radio[NUM_DEF_BUTTONS], *hbox, *label, *entry;
+	GtkWidget *vbox, *radio[NUM_DEF_BUTTONS], *hbox, *entry;
 	gboolean enable = FALSE;
 	int i, e = 0;
 	gchar *radio_label[] = {
@@ -229,7 +327,27 @@ static GtkWidget *p_create_frame_missing(struct LibravatarPrefsPage *page)
 		radio[i] = gtk_radio_button_new_with_label_from_widget(
 				(i > 0)? GTK_RADIO_BUTTON(radio[i - 1]): NULL, radio_label[i]);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio[i]), enable);
-		gtk_box_pack_start(GTK_BOX(vbox), radio[i], FALSE, FALSE, 0);
+		if (i == CUSTOM_URL_BUTTON_INDEX) {
+			/* set related entry next to radio button */
+			entry = gtk_entry_new_with_max_length(MAX_URL_LENGTH);
+			CLAWS_SET_TIP(entry, _("Enter the URL you want to be "
+				"redirected when no user icon is available. "
+				"Leave an empty URL to use the default "
+				"libravatar orange icon."));
+			gtk_widget_show(entry);
+			gtk_entry_set_text(GTK_ENTRY(entry),
+				libravatarprefs.default_mode_url);
+			hbox = gtk_hbox_new(FALSE, 6);
+			gtk_box_pack_start(GTK_BOX(hbox), radio[i], FALSE, FALSE, 0);
+			gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+			gtk_widget_set_sensitive(entry,
+				(libravatarprefs.default_mode == DEF_MODE_URL)
+				? TRUE: FALSE);
+			page->defm_url_text = entry;
+			gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+		} else {
+			gtk_box_pack_start(GTK_BOX(vbox), radio[i], FALSE, FALSE, 0);
+		}
 		g_signal_connect(radio[i], "toggled",
 				 G_CALLBACK(default_mode_radio_button_cb),
 				 (gpointer) &(radio_value[i]));
@@ -242,23 +360,11 @@ static GtkWidget *p_create_frame_missing(struct LibravatarPrefsPage *page)
 		libravatarprefs.default_mode = DEF_MODE_NONE;
 	}
 	/* don't waste time with headers that won't be displayed */
-	prefs_common.enable_avatars = (libravatarprefs.default_mode == DEF_MODE_NONE)
-						? AVATARS_ENABLE_BOTH: AVATARS_DISABLE;
+	prefs_common_get_prefs()->enable_avatars =
+		(libravatarprefs.default_mode == DEF_MODE_NONE)
+		? AVATARS_ENABLE_BOTH: AVATARS_DISABLE;
 
-	label = gtk_label_new(_("URL:"));
-	gtk_widget_show(label);
-	entry = gtk_entry_new_with_max_length(MAX_URL_LENGTH);
-	gtk_widget_show(entry);
-	gtk_entry_set_text(GTK_ENTRY(entry), libravatarprefs.default_mode_url);
 
-	hbox = gtk_hbox_new(FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
-	gtk_widget_set_sensitive(entry,
-		(libravatarprefs.default_mode == DEF_MODE_URL)? TRUE: FALSE);
-	page->defm_url_text = entry;
-
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
 	return vbox;
 }
@@ -315,6 +421,7 @@ static GtkWidget *p_create_frame_network(struct LibravatarPrefsPage *page)
   ┌─Icon cache───────────────────────────────────────────┐
   │ [✔] Use cached icons                                 │
   │ Cache refresh interval [ 24 |⬘] hours                │
+  │ Using X KB in Y files and Z directories [Clear]      │
   └──────────────────────────────────────────────────────┘
   ┌─Default missing icon mode────────────────────────────┐
   │ (•) None                                             │
@@ -323,8 +430,7 @@ static GtkWidget *p_create_frame_network(struct LibravatarPrefsPage *page)
   │ ( ) MonsterID                                        │
   │ ( ) Wavatar                                          │
   │ ( ) Retro                                            │
-  │ ( ) Custom URL                                       │
-  │     URL: [_________________________________________] │
+  │ ( ) Custom URL [___________________________________] │
   └──────────────────────────────────────────────────────┘
   ┌─Network──────────────────────────────────────────────┐
   │ [✔] Allow redirects                                  │
@@ -381,7 +487,7 @@ static void libravatar_save_config(void)
 		return;
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("Failed to write Libravatar configuration to file\n");
+		g_warning("failed to write Libravatar configuration to file");
 		prefs_file_close_revert(pfile);
 		return;
 	}
@@ -449,6 +555,7 @@ void libravatar_prefs_init(void)
 	libravatarprefs_page.page.create_widget = libravatar_prefs_create_widget_func;
 	libravatarprefs_page.page.destroy_widget = libravatar_prefs_destroy_widget_func;
 	libravatarprefs_page.page.save_page = libravatar_prefs_save_func;
+	libravatarprefs_page.page.weight = 40.0;
 
 	prefs_gtk_register_page((PrefsPage *) &libravatarprefs_page);
 }
