@@ -198,13 +198,19 @@ static void add_mailbox(GtkAction *action, gpointer callback_data)
 		return;
 	}
 	basename = g_path_get_basename(path);
+
+	if (!folder_local_name_ok(basename)) {
+		g_free(path);
+		g_free(basename);
+		return;
+	}
+
 	folder = folder_new(folder_get_class_from_string("mailmbox"), 
 			    !strcmp(path, "Mail") ? _("Mailbox") : basename,
 			    path);
-	g_free(basename);			    
+	g_free(basename);
 	g_free(path);
 
-
 	if (folder->klass->create_tree(folder) < 0) {
 		alertpanel_error(_("Creation of the mailbox failed.\n"
 				   "Maybe some files already exist, or you don't have the permission to write there."));
@@ -251,6 +257,9 @@ static void new_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 
+	if (!folder_local_name_ok(new_folder))
+		return;
+
 	name = trim_string(new_folder, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
 
@@ -418,6 +427,9 @@ static void rename_folder_cb(GtkAction *action, gpointer data)
 		return;
 	}
 
+	if (!folder_local_name_ok(new_folder))
+		return;
+
 	parent = folder_item_parent(item);
 	p = g_strconcat(parent->path ? parent->path : "", ".", new_folder, NULL);
 	if (folder_find_child_item_by_name(parent, p)) {
