@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> and 
+ * Copyright (C) 1999-2015 Colin Leroy <colin@colino.net> and
  * the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -706,9 +705,10 @@ add_new:
 
 GSList *vcal_get_events_list(FolderItem *item)
 {
-	DIR *dp;
-	struct dirent *d;
+	GDir *dp;
+	const gchar *d;
 	GSList *events = NULL;
+	GError *error = NULL;
 
 	if (item != item->folder->inbox) {
 		GSList *subs = vcal_folder_get_webcal_events_for_folder(item);
@@ -725,27 +725,29 @@ GSList *vcal_get_events_list(FolderItem *item)
 		return events;
 	}
 
-	dp = opendir(vcal_manager_get_event_path());
+	dp = g_dir_open(vcal_manager_get_event_path(), 0, &error);
 	
 	if (!dp) {
-		FILE_OP_ERROR(vcal_manager_get_event_path(), "opendir");
+		debug_print("couldn't open dir '%s': %s (%d)\n",
+				vcal_manager_get_event_path(), error->message, error->code);
+		g_error_free(error);
 		return 0;
 	}
 
-	while ((d = readdir(dp)) != NULL) {
+	while ((d = g_dir_read_name(dp)) != NULL) {
 		VCalEvent *event = NULL;
-		if (d->d_name[0] == '.' || strstr(d->d_name, ".bak")
-		||  !strcmp(d->d_name, "internal.ics")
-		||  !strcmp(d->d_name, "internal.ifb")
-		||  !strcmp(d->d_name, "multisync")) 
+		if (d[0] == '.' || strstr(d, ".bak")
+		||  !strcmp(d, "internal.ics")
+		||  !strcmp(d, "internal.ifb")
+		||  !strcmp(d, "multisync")) 
 			continue;
 
-		event = vcal_manager_load_event(d->d_name);
+		event = vcal_manager_load_event(d);
 		if (!event)
 			continue;
 		if (event->rec_occurence) {
 			vcal_manager_free_event(event);
-			claws_unlink(d->d_name);
+			claws_unlink(d);
 			continue;
 		}
 
@@ -771,7 +773,7 @@ GSList *vcal_get_events_list(FolderItem *item)
 				struct icaldurationtype ical_dur;
 				int i = 0;
 
-				debug_print("dumping recurring events from main event %s\n", d->d_name);
+				debug_print("dumping recurring events from main event %s\n", d);
         			recur = icalrecurrencetype_from_string(event->recur);
 				dtstart = icaltime_from_string(event->dtstart);
 
@@ -822,7 +824,7 @@ GSList *vcal_get_events_list(FolderItem *item)
 			vcal_manager_free_event(event);
 		}
 	}
-	closedir(dp);
+	g_dir_close(dp);
 	return g_slist_reverse(events);
 }
 
@@ -1124,7 +1126,7 @@ static gint vcal_remove_folder(Folder *folder, FolderItem *fitem)
 
 static gboolean vcal_scan_required(Folder *folder, FolderItem *item)
 {
-	struct stat s;
+	GStatBuf s;
 	VCalFolderItem *vitem = (VCalFolderItem *)item;
 
 	g_return_val_if_fail(item != NULL, FALSE);
@@ -1144,7 +1146,7 @@ static gint vcal_folder_lock_count = 0;
 
 static void vcal_set_mtime(Folder *folder, FolderItem *item)
 {
-	struct stat s;
+	GStatBuf s;
 	gchar *path = folder_item_get_path(item);
 
 	if (folder->inbox != item)
@@ -1702,7 +1704,7 @@ gboolean vcal_curl_put(gchar *url, FILE *fp, gint filesize, const gchar *user, c
 #endif
 	curl_easy_setopt(curl_ctx, CURLOPT_USERAGENT, 
 		"Claws Mail vCalendar plugin "
-		"(http://www.claws-mail.org/plugins.php)");
+		"(" PLUGINS_URI ")");
 	curl_easy_setopt(curl_ctx, CURLOPT_INFILESIZE, filesize);
 	res = curl_easy_perform(curl_ctx);
 	g_free(userpwd);
@@ -2134,6 +2136,43 @@ static gchar *get_email_from_property(icalproperty *p)
 	return email;
 }
 
+static void adjust_for_local_time_zone(icalproperty *eventtime, icalproperty *tzoffsetto, int dtstart)
+{
+	int tzoffset;
+	int loctzoffset;
+	time_t loctime, gmttime, evttime;
+	struct icaltimetype icaltime;
+
+	/* calculate local UTC offset */
+	loctime = time(NULL);
+	loctime = mktime(localtime(&loctime));
+	gmttime = mktime(gmtime(&loctime));
+	loctzoffset = loctime - gmttime;
+
+	if (eventtime && tzoffsetto) {
+		tzoffset = icalproperty_get_tzoffsetto(tzoffsetto);
+		if (dtstart) {
+			evttime = icaltime_as_timet(icalproperty_get_dtstart(eventtime));
+		}
+		else {
+			evttime = icaltime_as_timet(icalproperty_get_dtend(eventtime));
+		}
+
+		/* convert to UTC */
+		evttime -= tzoffset;
+		/* and adjust for local time zone */
+		evttime += loctzoffset;
+		icaltime = icaltime_from_timet(evttime, 0);
+
+		if (dtstart) {
+			icalproperty_set_dtstart(eventtime, icaltime);
+		}
+		else {
+			icalproperty_set_dtend(eventtime, icaltime);
+		} 
+	}
+}
+
 #define GET_PROP(comp,prop,kind) {						\
 	prop = NULL;								\
 	if (!(prop = icalcomponent_get_first_property(comp, kind))) {		\
@@ -2173,6 +2212,7 @@ VCalEvent *vcal_get_event_from_ical(const gchar *ical, const gchar *charset)
 	gchar *int_ical = g_strdup(ical);
 	icalcomponent *comp = icalcomponent_new_from_string(int_ical);
 	icalcomponent *inner = NULL;
+	icalcomponent *tzcomp = NULL;
 	icalproperty *prop = NULL;
 	GSList *list = NULL, *cur = NULL;
 	gchar *uid = NULL;
@@ -2216,6 +2256,31 @@ VCalEvent *vcal_get_event_from_ical(const gchar *ical, const gchar *charset)
 		TO_UTF8(summary);
 		icalproperty_free(prop);
 	}
+	tzcomp = icalcomponent_get_first_component(comp, ICAL_VTIMEZONE_COMPONENT);
+	if (tzcomp) {
+		icalproperty *evtstart = NULL;
+		icalproperty *evtend = NULL;
+		icalproperty *tzoffsetto = NULL;
+		icalcomponent *tzstd = NULL;
+
+		tzstd = icalcomponent_get_first_component(tzcomp, ICAL_XSTANDARD_COMPONENT);
+		tzoffsetto = icalcomponent_get_first_property(tzstd, ICAL_TZOFFSETTO_PROPERTY);
+
+		GET_PROP(comp, evtstart, ICAL_DTSTART_PROPERTY);
+		adjust_for_local_time_zone(evtstart, tzoffsetto, TRUE);
+
+		GET_PROP(comp, evtend, ICAL_DTEND_PROPERTY);
+		adjust_for_local_time_zone(evtend, tzoffsetto, FALSE);
+
+		if (tzoffsetto)
+			icalproperty_free(tzoffsetto);
+		if (evtstart)
+			icalproperty_free(evtstart);
+		if (evtend)
+			icalproperty_free(evtend);
+		if (tzstd)
+			icalcomponent_free(tzstd);
+	}
 	GET_PROP(comp, prop, ICAL_DTSTART_PROPERTY);
 	if (prop) {
 		dtstart = g_strdup(icaltime_as_ical_string(icalproperty_get_dtstart(prop)));
